@@ -848,10 +848,7 @@ class Builder(Update):
     class NvidiaDriver(Driver):
         Id = 'nvidia-drivers'
         Package = 'x11-drivers/nvidia-drivers'
-        if os.path.isdir('/var/db/repos/gentoo'):
-            Eclass = 'var/db/repos/gentoo/eclass/nvidia-driver.eclass'
-        else:	
-            Eclass = 'usr/portage/eclass/nvidia-driver.eclass'
+        Eclass = 'usr/portage/eclass/nvidia-driver.eclass'
         SkipVers = ('72.0.0', '97.0.0', '177.0.0', '305.0.0', '341.0.0')
         SkipVersNew = ('71', '96', '173', '304', '340', '367')
 
@@ -951,12 +948,8 @@ class Builder(Update):
 
         system_ini = SystemIni(self.clVars.Get('cl_builder_linux_datavars'))
         driver_list = list(self.NvidiaDriver(builder_path, system_ini))
-        if os.path.isdir('/var/db/repos/gentoo'):
-            distrdir = path.join(builder_path, 'var/calculate/distfiles')
-            pkgdir = path.join(builder_path, 'var/calculate/packages')
-        else:
-            distrdir = path.join(builder_path, 'usr/portage/distfiles')
-            pkgdir = path.join(builder_path, 'usr/portage/packages')
+        distrdir = path.join(builder_path, 'usr/portage/distfiles')
+        pkgdir = path.join(builder_path, 'usr/portage/packages')
         for target_dn in (distrdir, pkgdir):
             makeDirectory(target_dn)
             chmod(target_dn, distrdir_perm)
@@ -1009,7 +1002,7 @@ class Builder(Update):
                                   % driver_list[0][0])
                 time.sleep(10)
 
-        self.startTask(_("Cleaning and copying driver files"))
+        self.startTask(_("Cleaning driver files"))
         for source_dn, source, target_dn, target in [
             (builder_distdir, distdir_files,
              distrdir, find(distrdir,
@@ -1024,12 +1017,6 @@ class Builder(Update):
                 if fn not in source:
                     removeFileWithEmptyDirectory(path.join(target_dn, fn),
                                                  stopDirectory=target_dn)
-            if not os.path.isdir('/var/db/repos/gentoo'):
-                # копируем отсутствующие файлы
-                for fn in source:
-                    if fn not in target:
-                        copyWithPath(path.join(source_dn, fn),
-                                     target_dn, prefix=source_dn)
 
         return True
 
@@ -1082,12 +1069,8 @@ class Builder(Update):
         cache_file = self.clVars.Get('builder.cl_builder_video_driver_path')
         if path.exists(cache_file):
             removeFileWithEmptyDirectory(cache_file)
-        if os.path.isdir('/var/db/repos/gentoo'):
-            distrdir = path.join(builder_path, 'var/calculate/distfiles')
-            pkgdir = path.join(builder_path, 'var/calculate/packages')
-        else:
-            distrdir = path.join(builder_path, 'usr/portage/distfiles')
-            pkgdir = path.join(builder_path, 'usr/portage/packages')
+        distrdir = path.join(builder_path, 'usr/portage/distfiles')
+        pkgdir = path.join(builder_path, 'usr/portage/packages')
         for target_dn, target in [
             (distrdir, find(distrdir,
                             fullpath=False)),
